package com.ruoyi.mall.service;

import com.ruoyi.mall.domain.MallBatch;
import com.ruoyi.mall.domain.Vo.BatchVO;

import java.math.BigDecimal;
import java.util.List;

/**
 * 录取批次Service接口
 *
 * @author Lsm
 * @date 2023-10-18
 */
public interface IMallBatchService
{
    /**
     * 查询录取批次
     *
     * @param mallBatchId 录取批次主键
     * @return 录取批次
     */
    public MallBatch selectMallBatchByMallBatchId(Long mallBatchId);

    /**
     * 查询录取批次列表
     *
     * @param mallBatch 录取批次
     * @return 录取批次集合
     */
    public List<MallBatch> selectMallBatchList(MallBatch mallBatch);

    /**
     * 新增录取批次
     *
     * @param mallBatch 录取批次
     * @return 结果
     */
    public int insertMallBatch(MallBatch mallBatch);

    /**
     * 修改录取批次
     *
     * @param mallBatch 录取批次
     * @return 结果
     */
    public int updateMallBatch(MallBatch mallBatch);

    /**
     * 批量删除录取批次
     *
     * @param mallBatchIds 需要删除的录取批次主键集合
     * @return 结果
     */
    public int deleteMallBatchByMallBatchIds(Long[] mallBatchIds);

    /**
     * 删除录取批次信息
     *
     * @param mallBatchId 录取批次主键
     * @return 结果
     */
    public int deleteMallBatchByMallBatchId(Long mallBatchId);

    /**
     * 批次查询列表
     * @return 结果
     */
    public List<BatchVO> selectBatchList();

    /**
     * 所有批次查询列表
     * @return 结果
     */
    public List<BatchVO> selectAllBatchList();
}
